@@ -16,7 +16,7 @@ from trdb2py.plotly import (showAssetCandles, showHeatmap, showHeatmapWinRateInY
                             showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths,
                             showBarWinRateInMonths, showBarWinRateInYears, showBarWinRate4Month,
                             showPNL, showPNLs, showPNLs2, showBarResponseRateInYears,
-                            showAssetCandles2, showIndicators)
+                            showAssetCandles2, showIndicators, showIndicatorPie)
 from trdb2py.trdb2utils import (analysisResult, getIndicatorInResult, getFirstCtrlTs, buildPNLDataFrame,
                                 sortIndicator)
 import trdb2py.trading2_pb2
